pub fn parse_script(script: &[u8]) -> Result<Vec<Instruction>, ScriptError>Expand description
Parse a serialized script using HSD’s pushdata encoding and consensus size bound. Push-size policy is enforced by execution so callers can inspect a syntactically valid script containing an oversized push.